from distutils.core import setup

setup(
		name      	 ='nestertest123',
		version 	 ='1.2.1',
		py_modules   =['nestertest123'],
		author  	 ='hfpython',
		author_email ='ceshi@163.com',
		url			 ='http://www.testerhome.com',
		description  ='A simple printer of nested lists', 
	)
